
# Enum: activation_enum


Enums containing possible values for activation functions.

URI: [https://w3id.org/neat/activation_enum](https://w3id.org/neat/activation_enum)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| linear | Linear function. |  |  |
| relu | Rectified Linear Unit (ReLU) |  |  |
| sigmoid | Sigmoid activation function. |  |  |
| tanh | The tanh function. |  |  |
| softmax | Softmax (or softargmax) function. |  |  |

